@@ -124,6 +124,7 @@ TENTACLES_EVALUATOR_SOCIAL_PATH = "Social"
 TENTACLES_EVALUATOR_STRATEGIES_PATH = "Strategies"
 TENTACLES_EVALUATOR_UTIL_PATH = "Util"
 TENTACLES_TRADING_MODE_PATH = "Mode"
+TENTACLES_TRADING_SUPERVISOR_PATH = "Supervisor"
 TENTACLES_TRADING_EXCHANGE_PATH = "Exchange"
 TENTACLES_WEBSOCKETS_FEEDS_PATH = "feeds"
 
@@ -185,6 +186,7 @@ TENTACLES_FOLDERS_ARCH = {
     ],
     TENTACLES_TRADING_PATH: [
         TENTACLES_TRADING_MODE_PATH,
+        TENTACLES_TRADING_SUPERVISOR_PATH,
         TENTACLES_TRADING_EXCHANGE_PATH
     ]
 }
@@ -195,7 +197,6 @@ TENTACLE_MODULE_FOLDERS = {
     TENTACLE_TESTS
 }
 
-
 # tentacles files management
 TENTACLE_TYPES = [
     TENTACLES_BACKTESTING_PATH,
